Module beamlit.models.acl
=========================

Classes
-------

`ACL(created_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, updated_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, id: beamlit.types.Unset | str = <beamlit.types.Unset object>, resource_id: beamlit.types.Unset | str = <beamlit.types.Unset object>, resource_type: beamlit.types.Unset | str = <beamlit.types.Unset object>, role: beamlit.types.Unset | str = <beamlit.types.Unset object>, subject_id: beamlit.types.Unset | str = <beamlit.types.Unset object>, subject_type: beamlit.types.Unset | str = <beamlit.types.Unset object>, workspace: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   ACL
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        id (Union[Unset, str]): ACL id
        resource_id (Union[Unset, str]): Resource ID
        resource_type (Union[Unset, str]): Resource type
        role (Union[Unset, str]): Role
        subject_id (Union[Unset, str]): Subject ID
        subject_type (Union[Unset, str]): Subject type
        workspace (Union[Unset, str]): Workspace name
    
    Method generated by attrs for class ACL.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `created_at: beamlit.types.Unset | str`
    :

    `id: beamlit.types.Unset | str`
    :

    `resource_id: beamlit.types.Unset | str`
    :

    `resource_type: beamlit.types.Unset | str`
    :

    `role: beamlit.types.Unset | str`
    :

    `subject_id: beamlit.types.Unset | str`
    :

    `subject_type: beamlit.types.Unset | str`
    :

    `updated_at: beamlit.types.Unset | str`
    :

    `workspace: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :